@@ -1355,58 +1355,6 @@ setMethod("getWhat", "EnsDb",
               return(Res)
           })
 
-############################################################
-## disjointExons
-##
-## that's similar to the code from the GenomicFeatures package.
-setMethod("disjointExons", "EnsDb",
-          function(x, aggregateGenes = FALSE, includeTranscripts = TRUE,
-                   filter = AnnotationFilterList(), ...){
-              filter <- .processFilterParam(filter, x)
-
-              exonsByGene <- exonsBy(x, by = "gene", filter = filter)
-              exonicParts <- disjoin(unlist(exonsByGene, use.names = FALSE))
-
-              if (aggregateGenes) {
-                  foGG <- findOverlaps(exonsByGene, exonsByGene)
-                  aggregateNames <- GenomicFeatures:::.listNames(names(exonsByGene),
-                                                                 as.list(foGG))
-                  foEG <- findOverlaps(exonicParts, exonsByGene, select="first")
-                  gene_id <- aggregateNames[foEG]
-                  pasteNames <- GenomicFeatures:::.pasteNames(names(exonsByGene),
-                                                              as.list(foGG))[foEG]
-                  orderByGeneName <- order(pasteNames)
-                  exonic_rle <- runLength(Rle(pasteNames[orderByGeneName]))
-              } else {
-                  ## drop exonic parts that overlap > 1 gene
-                  foEG <- findOverlaps(exonicParts, exonsByGene)
-                  idxList <- as.list(foEG)
-                  if (any(keep <- countQueryHits(foEG) == 1)) {
-                      idxList <- idxList[keep]
-                      exonicParts <- exonicParts[keep]
-                  }
-                  gene_id <- GenomicFeatures:::.listNames(names(exonsByGene),
-                                                          idxList)
-                  orderByGeneName <- order(unlist(gene_id, use.names=FALSE))
-                  exonic_rle <- runLength(Rle(unlist(gene_id[orderByGeneName],
-                                                     use.names=FALSE)))
-              }
-              values <- DataFrame(gene_id)
-
-              if (includeTranscripts) {
-                  exonsByTx <- exonsBy(x, by="tx", filter=filter)
-                  foET <- findOverlaps(exonicParts, exonsByTx)
-                  values$tx_name <- GenomicFeatures:::.listNames(names(exonsByTx),
-                                                                 as.list(foET))
-              }
-              mcols(exonicParts) <- values
-              exonicParts <- exonicParts[orderByGeneName]
-              exonic_part <- unlist(lapply(exonic_rle, seq_len), use.names=FALSE)
-              exonicParts$exonic_part <- exonic_part
-              return(exonicParts)
-          }
-         )
-
 ############################################################
 ## getGeneRegionTrackForGviz
 ## Fetch data to add as a GeneTrack.
