@@ -38,10 +38,9 @@ head(Tx$tx_biotype)
 transcripts(edb, filter = ~ gene_name == "ZBTB16")
 
 ## ----transcripts-filter, message = FALSE--------------------------------------
-library(magrittr)
-
-edb %>% filter(~ symbol == "BCL2" & tx_biotype != "protein_coding") %>%
-    transcripts
+edb |>
+filter(~ symbol == "BCL2" & tx_biotype != "protein_coding") |>
+transcripts()
 
 ## ----filter-Y-----------------------------------------------------------------
 edb_y <- addFilter(edb, SeqNameFilter("Y"))
@@ -155,9 +154,10 @@ TxByGns
 
 ## ----disjointExons, message = FALSE, eval = FALSE-----------------------------
 #  ## Create a GRanges of non-overlapping exon parts.
-#  DJE <- disjointExons(edb, filter = AnnotationFilterList(
-#  			      SeqNameFilter(c(1:22, "X", "Y")),
-#  			      GeneIdFilter("ENSG%", "startsWith")))
+#  edb_sub <- filter(edb, filter = AnnotationFilterList(
+#                             SeqNameFilter(c(1:22, "X", "Y")),
+#                             GeneIdFilter("ENSG%", "startsWith")))
+#  DJE <- exonicParts(edb_sub)
 
 ## ----transcript-sequence-AnnotationHub, message = FALSE, eval = FALSE---------
 #  library(EnsDb.Hsapiens.v86)
@@ -301,7 +301,8 @@ lincs <- getGeneRegionTrackForGviz(edb, chromosome = "chrY",
 				   filter = GeneBiotypeFilter("lincRNA"))
 
 plotTracks(list(gat, GeneRegionTrack(protCod, name = "protein coding"),
-		GeneRegionTrack(lincs, name = "lincRNAs")), transcriptAnnotation = "symbol")
+		GeneRegionTrack(lincs, name = "lincRNAs")),
+        transcriptAnnotation = "symbol")
 
 ## At last we change the seqlevels style again to Ensembl
 seqlevelsStyle <- "Ensembl"
@@ -353,7 +354,7 @@ select(edb, keys = c("BCL2", "BCL2L11"), keytype = "GENENAME",
 
 ## Use the filtering system of ensembldb
 select(edb, keys = ~ gene_name %in% c("BCL2", "BCL2L11") &
-		tx_biotype == "protein_coding",
+                tx_biotype == "protein_coding",
        columns = c("GENEID", "GENENAME", "TXID", "TXBIOTYPE"))
 
 
@@ -445,7 +446,7 @@ Y
 
 ## Create the EnsDb database file
 DB <- ensDbFromGRanges(Y, path = tempdir(), version = 75,
-		       organism = "Homo_sapiens")
+                       organism = "Homo_sapiens")
 
 ## Load the database
 edb <- EnsDb(DB)
